@@ -30,6 +30,7 @@
 #include "objprops.h"
 #include "vector.h"
 #include "xml-utils.h"
+#include <glib/gi18n-lib.h>
 #include <cmath>
 #include <cstring>
 #include <sstream>
@@ -356,4 +357,9 @@ Vector Atom::GetVector () const
 	return Vector (m_x, m_y, m_z);
 }
 
+std::string Atom::Name ()
+{
+	return _("Atom");
+}
+
 }	//	namespace gcu
