@@ -35,9 +35,9 @@ gcu_cc_error_error (G_GNUC_UNUSED GOCmdContext *cc, GError *error)
 }
 
 static void
-gcu_cc_error_info (G_GNUC_UNUSED GOCmdContext *cc, ErrorInfo *error)
+gcu_cc_error_info (G_GNUC_UNUSED GOCmdContext *cc, GOErrorInfo *error)
 {
-	error_info_print (error);
+	go_error_info_print (error);
 }
 
 static char *
@@ -54,7 +54,7 @@ gcu_cc_set_sensitive (G_GNUC_UNUSED GOCmdContext *cc,
 }
 
 static void
-gcu_cc_progress_set (G_GNUC_UNUSED GOCmdContext *cc, G_GNUC_UNUSED gfloat val)
+gcu_cc_progress_set (G_GNUC_UNUSED GOCmdContext *cc, G_GNUC_UNUSED double val)
 {
 }
 
