@@ -116,7 +116,7 @@ void CrystalAtom::SetColor(float red, float green, float blue, float alpha)
 
 void CrystalAtom::SetDefaultColor()
 {
-	if (!GetZ())
+	if (GetZ () < 1)
 		return;
 	m_bCustomColor = false;
 	double *Colors = Element::GetElement(GetZ())->GetDefaultColor();
@@ -159,8 +159,10 @@ bool CrystalAtom::operator==(CrystalAtom& caAtom)
 	return ((fabs (x() - caAtom.x()) < PREC) &&
 			(fabs (y() - caAtom.y()) < PREC) &&
 			(fabs (z() - caAtom.z()) < PREC) &&
-			(GetZ () == caAtom.GetZ ()) &&
-			(GetCharge () == caAtom.GetCharge ())) ;
+			((GetZ () > 0)? GetZ () == caAtom.GetZ (): GetZ () == caAtom.GetZ () &&
+			 m_fRed == caAtom.m_fRed && m_fGreen == caAtom.m_fGreen && m_fBlue == caAtom.m_fBlue && m_fAlpha == caAtom.m_fAlpha
+			 && GetSize () == caAtom.GetSize ()) &&
+			(GetCharge () == caAtom.GetCharge ()));
 }
 
 double CrystalAtom::ScalProd(int h, int k, int l)
@@ -233,13 +235,13 @@ bool CrystalAtom::SetProperty (unsigned property, char const *value)
 	case GCU_PROP_Z:
 		break;
 	case GCU_PROP_XFRACT:
-		m_x = strtod (value, NULL) * GetDocument ()->GetScale ();
+		m_x = strtod (value, NULL);
 		break;
 	case GCU_PROP_YFRACT:
-		m_y = strtod (value, NULL) * GetDocument ()->GetScale ();
+		m_y = strtod (value, NULL);
 		break;
 	case GCU_PROP_ZFRACT:
-		m_z = strtod (value, NULL) * GetDocument ()->GetScale ();
+		m_z = strtod (value, NULL);
 		break;
 	default:
 		return Atom::SetProperty (property, value);
