@@ -159,20 +159,6 @@ void CrystalDoc::ParseXMLTree (xmlNode* xml)
 	m_SpaceGroup = NULL;
 	old_num_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
 	setlocale (LC_NUMERIC, "C");
-	//look for generator node
-	unsigned version = 0xffffff , major, minor, micro;
-	node = xml->children;
-	while (node) {
-		if (!strcmp ((const char*)(node->name), "generator"))
-			break;
-		node = node->next;
-	}
-	if (node) {
-		txt = (char*) xmlNodeGetContent (node);
-		if (sscanf(txt, "Gnome Crystal %d.%d.%d", &major, &minor, &micro) == 3)
-			version = micro + minor * 0x100 + major * 0x10000;
-		xmlFree (txt);
-	}
 	node = xml->children;
 	while(node) {
 		if (!strcmp ((gchar*) node->name, "text"));
@@ -836,8 +822,15 @@ bool CrystalDoc::Loaded () throw (LoaderError)
 		m_alpha = m_beta = m_gamma  = 90;
 		break;
 	case rhombohedral:
-		m_beta = m_gamma = m_alpha;
-		m_b = m_c = m_a;
+		if (m_alpha != 90) {
+			m_beta = m_gamma = m_alpha;
+			m_b = m_c = m_a;
+		} else {
+			// looks like the usual convention, at least in CIF files.
+			m_alpha = m_beta = 90;
+			m_gamma  = 120;
+			m_b = m_a;
+		}
 		break;
 	case monoclinic:
 	case base_centered_monoclinic:
@@ -855,22 +848,22 @@ bool CrystalDoc::SetProperty (unsigned property, char const *value)
 {
 	switch (property) {
 	case GCU_PROP_CELL_A:
-		m_a = strtod (value, NULL) * GetScale ();
+		m_a = g_ascii_strtod (value, NULL) * GetScale ();
 		break;
 	case GCU_PROP_CELL_B:
-		m_b = strtod (value, NULL) * GetScale ();
+		m_b = g_ascii_strtod (value, NULL) * GetScale ();
 		break;
 	case GCU_PROP_CELL_C:
-		m_c = strtod (value, NULL) * GetScale ();
+		m_c = g_ascii_strtod (value, NULL) * GetScale ();
 		break;
 	case GCU_PROP_CELL_ALPHA:
-		m_alpha = strtod (value, NULL);
+		m_alpha = g_ascii_strtod (value, NULL);
 		break;
 	case GCU_PROP_CELL_BETA:
-		m_beta = strtod (value, NULL);
+		m_beta = g_ascii_strtod (value, NULL);
 		break;
 	case GCU_PROP_CELL_GAMMA:
-		m_gamma = strtod (value, NULL);
+		m_gamma = g_ascii_strtod (value, NULL);
 		break;
 	case GCU_PROP_CHEMICAL_NAME_COMMON:
 		m_NameCommon = value;
@@ -909,11 +902,12 @@ bool CrystalDoc::SetProperty (unsigned property, char const *value)
 			}
 		else if (id <= 142)
 			m_lattice = (type == 'P')? tetragonal: body_centered_tetragonal;
-		else if (id <= 167)
-			m_lattice = rhombohedral;
-		else if (id <= 194)
-			m_lattice = hexagonal;
-		else {
+		else if (id <= 194) {
+			if (id == 146 || id == 148 || id == 155 || id == 160 || id == 161 || id == 166 || id == 167)
+				m_lattice = rhombohedral;
+			else
+				m_lattice = hexagonal;
+		} else {
 			switch (type) {
 			case 'P':
 				m_lattice = cubic;
