@@ -70,7 +70,7 @@ CIFLoader::CIFLoader ()
 	KnownProps["_cell_length_a"] = GCU_PROP_CELL_A;
 	KnownProps["_cell_length_b"] = GCU_PROP_CELL_B;
 	KnownProps["_cell_length_c"] = GCU_PROP_CELL_C;
-	KnownProps["_cell_angle_apha"] = GCU_PROP_CELL_ALPHA;
+	KnownProps["_cell_angle_alpha"] = GCU_PROP_CELL_ALPHA;
 	KnownProps["_cell_angle_beta"] = GCU_PROP_CELL_BETA;
 	KnownProps["_cell_angle_gamma"] = GCU_PROP_CELL_GAMMA;
 
@@ -86,6 +86,7 @@ CIFLoader::CIFLoader ()
 	KnownProps["_atom_site_fract_x"] = GCU_PROP_XFRACT;
 	KnownProps["_atom_site_fract_y"] = GCU_PROP_YFRACT;
 	KnownProps["_atom_site_fract_z"] = GCU_PROP_ZFRACT;
+	KnownProps["_atom_site_aniso_label"] = CIF_ATOM_LABEL;
 }
 
 CIFLoader::~CIFLoader ()
@@ -123,6 +124,8 @@ ContentType CIFLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char co
 	list <unsigned>::iterator loop_prop;
 	list <string> loop_values;
 	map <string, CIFAtomType> AtomTypes;
+	map <string, Object *> LabeledAtoms;
+	doc->SetProperty (GCU_PROP_SPACE_GROUP, "P 1");
 	SpaceGroup *group = new SpaceGroup ();
 	bool author_found = false;
 	doc->SetScale (100.); // lentghs and positions pus be converted to pm
@@ -191,6 +194,9 @@ ContentType CIFLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char co
 					if (in_loop) {
 						prop = KnownProps.find (key);
 						loop_contents.push_back ((prop == KnownProps.end ())? static_cast <unsigned> (GCU_PROP_MAX): (*prop).second);
+						// initialize loop_prop there because loop_ might be erroneously followed by
+						// just a property and its value.
+						loop_prop = loop_contents.begin ();
 						if (loop_type == LOOP_UNKNOWN) {
 							if (!key.compare (0, 11, "_atom_type_", 11))
 								loop_type = LOOP_ATOM_TYPE;
@@ -222,6 +228,7 @@ ContentType CIFLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char co
 					continue; // FIXME: this should not happen
 				if (*cur == 0) {
 					in_loop = false;
+					waiting_value = false;
 				} else {
 					while (*cur) {
 						while (*cur == ' ')
@@ -247,6 +254,7 @@ ContentType CIFLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char co
 						*next = endstr;
 						cur = next;
 						loop_prop++;
+						waiting_value = true; // fixes a loop with just a key and value on the same line
 						loop_values.push_back (value);
 						if (loop_prop == loop_contents.end ()) {
 							// store the values
@@ -254,25 +262,70 @@ ContentType CIFLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char co
 							case LOOP_ATOM: {
 								double scale = doc->GetScale ();
 								doc->SetScale (1.);
-								Object *atom = Object::CreateObject ("atom", doc);
+								Object *atom = Object::CreateObject ("atom", NULL);
 								for (loop_prop = loop_contents.begin (); loop_prop != loop_contents.end (); loop_prop++) {
 									std::string val = loop_values.front ();
 									loop_values.pop_front ();
 									switch (*loop_prop) {
 									case CIF_ATOM_LABEL: {
+										map <string, Object *>::iterator at = LabeledAtoms.find (val);
+										if (at != LabeledAtoms.end ()) {
+											delete atom;
+											atom = (*at).second;
+										} else {
+											LabeledAtoms[val] = atom;
+											doc->AddChild (atom);
+										}
 										if (AtomTypes.empty ()) {
 											int i = 0;
 											while (g_ascii_isalpha (val[i]))
 												i++;
 											val = val.substr (0, i);
-											atom->SetProperty (GCU_PROP_ATOM_SYMBOL, val.c_str ());
+											int z = Element::Z (val.c_str ());
+											while (i  && !z) {
+												i--;
+												val[i] = 0;
+												z = Element::Z (val.c_str ());
+											}
+											if (z > 0)
+												atom->SetProperty (GCU_PROP_ATOM_SYMBOL, val.c_str ());
 										}
 										break;
 									}
 									case CIF_ATOM_SITE_SYMBOL: {
-										CIFAtomType t = AtomTypes[val];
-										atom->SetProperty (GCU_PROP_ATOM_Z, t.elt.c_str ());
-										atom->SetProperty (GCU_PROP_ATOM_CHARGE, t.charge.c_str ());
+										if (AtomTypes.empty ()) {
+											int i = 0;
+											while (g_ascii_isalpha (val[i]))
+												i++;
+											val = val.substr (0, i);
+											int z = Element::Z (val.c_str ());
+											while (i  && !z) {
+												i--;
+												val[i] = 0;
+												z = Element::Z (val.c_str ());
+											}
+											if (z)
+												atom->SetProperty (GCU_PROP_ATOM_SYMBOL, val.c_str ());
+										} else {
+											if (AtomTypes.find (val) != AtomTypes.end ()) {
+												CIFAtomType t = AtomTypes[val];
+												atom->SetProperty (GCU_PROP_ATOM_Z, t.elt.c_str ());
+												atom->SetProperty (GCU_PROP_ATOM_CHARGE, t.charge.c_str ());
+											} else {
+												int i = 0;
+												while (g_ascii_isalpha (val[i]))
+													i++;
+												val = val.substr (0, i);
+												int z = Element::Z (val.c_str ());
+												while (i  && !z) {
+													i--;
+													val[i] = 0;
+													z = Element::Z (val.c_str ());
+												}
+												if (z > 0)
+													atom->SetProperty (GCU_PROP_ATOM_SYMBOL, val.c_str ());
+												}
+										}
 										break;
 									}
 									default:
@@ -381,18 +434,38 @@ ContentType CIFLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char co
 			continue;
 		}
 	}
-	// check ymmetry
+	// check symmetry
 	if (!group->IsValid ()) {
-		GtkWidget *w = gtk_message_dialog_new (doc->GetGtkWindow (), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("Invalid symmetry group."));
-		g_signal_connect (G_OBJECT (w), "response", G_CALLBACK (gtk_widget_destroy), NULL);
-		gtk_widget_show_all (w);
+		if (group->GetTransformsNumber ()) {
+			GtkWidget *w = gtk_message_dialog_new (doc->GetGtkWindow (), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("Invalid symmetry group."));
+			g_signal_connect (G_OBJECT (w), "response", G_CALLBACK (gtk_widget_destroy), NULL);
+			gtk_widget_show_all (w);
+		}
+		SpaceGroup const *sp = SpaceGroup::GetSpaceGroup (group->GetId ());
+		if (!sp)
+			sp = SpaceGroup::GetSpaceGroup (group->GetHMName ());
+		if (!sp)
+			sp = SpaceGroup::GetSpaceGroup (group->GetHallName ());
+		if (sp)
+			doc->SetProperty (GCU_PROP_SPACE_GROUP, sp->GetHallName ().c_str ());
 	} else {
 		SpaceGroup const *sp = SpaceGroup::Find (group);
 		if (sp)
 			doc->SetProperty (GCU_PROP_SPACE_GROUP, sp->GetHallName ().c_str ());
+		else {
+			group->RegisterSpaceGroup (0);
+			std::string name = group->GetHallName ();
+			if (name.length () == 0)
+				name = group->GetHMName ();
+			if (name.length () > 0)
+				doc->SetProperty (GCU_PROP_SPACE_GROUP, name.c_str ());
+			// FIXME: implement use of Id if available
+			group = NULL; // do not delete
+		}
 	}
 read_exit:
-	delete group;
+	if (group)
+		delete group;
 	g_object_unref (input);
 	return type;
 }
